==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/USERWIDGETLAYOUTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for USERWIDGETLAYOUTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USERWIDGETLAYOUTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERWIDGETLAYOUTID_Type", propOrder = {
    "usercode",
    "functionid",
    "line"
})
public class USERWIDGETLAYOUTID_Type {

    @XmlElement(name = "USERCODE", required = true)
    protected String usercode;
    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "LINE")
    protected long line;

    /**
     * Gets the value of the usercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Sets the value of the usercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the line property.
     * 
     */
    public long getLINE() {
        return line;
    }

    /**
     * Sets the value of the line property.
     * 
     */
    public void setLINE(long value) {
        this.line = value;
    }

}

==> eam-wshub-proxyclient-12.2-8-sources.jar: net/datastream/schemas/mp_fields/USERWIDGETLAYOUTID_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for USERWIDGETLAYOUTID_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="USERWIDGETLAYOUTID_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERCODE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}OVERVIEWTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FUNCTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LINE"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "USERWIDGETLAYOUTID_Type", propOrder = {
    "usercode",
    "overviewtemplateid",
    "functionid",
    "line"
})
public class USERWIDGETLAYOUTID_Type {

    @XmlElement(name = "USERCODE")
    protected String usercode;
    @XmlElement(name = "OVERVIEWTEMPLATEID")
    protected STANDARDENTITYID_Type overviewtemplateid;
    @XmlElement(name = "FUNCTIONID", required = true)
    protected FUNCTIONID_Type functionid;
    @XmlElement(name = "LINE")
    protected long line;

    /**
     * Gets the value of the usercode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUSERCODE() {
        return usercode;
    }

    /**
     * Sets the value of the usercode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUSERCODE(String value) {
        this.usercode = value;
    }

    /**
     * Gets the value of the overviewtemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public STANDARDENTITYID_Type getOVERVIEWTEMPLATEID() {
        return overviewtemplateid;
    }

    /**
     * Sets the value of the overviewtemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link STANDARDENTITYID_Type }
     *     
     */
    public void setOVERVIEWTEMPLATEID(STANDARDENTITYID_Type value) {
        this.overviewtemplateid = value;
    }

    /**
     * Gets the value of the functionid property.
     * 
     * @return
     *     possible object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public FUNCTIONID_Type getFUNCTIONID() {
        return functionid;
    }

    /**
     * Sets the value of the functionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link FUNCTIONID_Type }
     *     
     */
    public void setFUNCTIONID(FUNCTIONID_Type value) {
        this.functionid = value;
    }

    /**
     * Gets the value of the line property.
     * 
     */
    public long getLINE() {
        return line;
    }

    /**
     * Sets the value of the line property.
     * 
     */
    public void setLINE(long value) {
        this.line = value;
    }

}
